.. currentmodule:: chico_dico


Version 1.0.1
-------------

Released 2025-06-29

-   Added two Gradio WebUI: `chico` and `dico`.


Version 1.0.0
-------------

Released 2025-06-21

-   Initial release.
